@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000-2005  The PARI group.
+Copyright (C) 2000-2013  The PARI group.
 
 This file is part of the GP2C package.
 
@@ -10,7 +10,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
 
 /*Patch for list of gp functions. Must be include after header.h.*/
 typedef enum {GPuser_private,
@@ -18,10 +18,11 @@ typedef enum {GPuser_private,
               GPinstall,GPaddhelp,
               GPgrandO,
               GPbreak,GPnext,GPreturn,
-              GPfor,GPforstep,GPforstepvec,GPforprime,GPforvec,GPfordiv,
+              GPfor,GPforstep,GPforstepvec,GPforprime,GPforvec,
+              GPfordiv,GPfordivfactored,
               GPdoloop,
               GPlabel,
-              GPglobal,GPlocal,
+              GPglobal,GPlocal,GPlocalbitprec,GPlocalprec,
               GPif,
               GPprod,GPsum,GPsumdiv,GPprodeuler,
               GPuntil,GPwhile,GPwhilenull,
@@ -29,7 +30,7 @@ typedef enum {GPuser_private,
               GPvector,GPvectorsmall,GPvectorv,GPmatrix,
               GPiferr,
               GPinitfunc,GPcopyarg,
-              GPclosure
+              GPclosure, GPself
 } GPspec_private;
 
 struct patchfunc_s
@@ -47,16 +48,20 @@ struct patchfunc_s
 {"next",NULL,Gvoid,0,GPnext},
 {"for","GGIG",Gnotype,(1<<Msemicolon),GPfor},
 {"fordiv",NULL,Gnotype,(1<<Msemicolon),GPfordiv},
+{"fordivfactored",NULL,Gnotype,(1<<Msemicolon),GPfordivfactored},
 {"forstep","GIGGGG",Gnotype,(1<<Msemicolon),GPforstep},
 {"global",NULL,Gnotype,(1<<Msemicolon),GPglobal},
 {"if","GII",Gnotype,(1<<Msemicolon),GPif},
 {"iferr","IEII",Gnotype,(1<<Msemicolon),GPiferr},
 {"install",NULL,Gnotype,(1<<Msemicolon),GPinstall},
 {"local",NULL,Gnotype,(1<<Msemicolon),GPlocal},
+{"localbitprec","G",Gvoid,0,GPlocalbitprec},
+{"localprec","G",Gvoid,0,GPlocalprec},
 {"my",NULL,Gnotype,(1<<Msemicolon),GPlocal},
-{"prod","NULL",Gnotype,(1<<Msemicolon),GPprod},
+{"prod",NULL,Gnotype,(1<<Msemicolon),GPprod},
 {"prodeuler",NULL,Gnotype,(1<<Msemicolon),GPprodeuler},
 {"return",NULL,Gnotype,(1<<Mterm),GPreturn},
+{"self","",Gclosure,0,GPself},
 {"sum",NULL,Gnotype,(1<<Msemicolon),GPsum},
 {"sumdiv",NULL,Gnotype,(1<<Msemicolon),GPsumdiv},
 {"until","EI",Gnotype,(1<<Msemicolon),GPuntil},
